@@ -180,7 +180,7 @@ Bool ExtGetDriverData(FGLRXDriverDataPtr pDriverData)
         TRACE_XEXT("pDriverData->HasSecondary = %d\n",pDriverData->HasSecondary);
 
         pDriverData->ChipType           = rep.usChipType;
-        pDriverData->VideoRam           = rep.usVideoRam;
+        pDriverData->ulVideoRam         = rep.ulVideoRam;
         strcpy(pDriverData->sATiRevID,rep.sATiRevID);
         pDriverData->usAGPTransferMode  = rep.AGPTransferMode;
         pDriverData->uiAGPCapPtr        = rep.AGPCapPtr;
@@ -190,6 +190,7 @@ Bool ExtGetDriverData(FGLRXDriverDataPtr pDriverData)
         pDriverData->ulGamma2           = rep.ulGamma2;
         pDriverData->ulDesktopSetup     = rep.ulDesktopSetup;
         pDriverData->ulPrimary          = rep.ulPrimary;
+        strncpy(pDriverData->sBoardName,rep.sBoardName, sizeof(pDriverData->sBoardName) );
 
         TRACE_XEXT("maj /min/boardt. %d %d %x pDriverData->ulGamma1,2:  %x %x\n", rep.majorVersion,
             rep.minorVersion, rep.usBoardType, pDriverData->ulGamma1,pDriverData->ulGamma2 );
