@@ -6,8 +6,8 @@ class Sheet : public QTabDialog
     Q_OBJECT
 
 public:
-    Sheet( QWidget *parent, const char *name, bool big_info, bool has_dual, bool has_gamma );
-    
+    Sheet( QWidget *parent, const char *name, bool big_info, bool has_dual, bool has_gamma, WFlags flags );
+
 private slots:
     void OnApply();
     void OnCancel();
