@@ -12,7 +12,6 @@ logfile=$current_wd/make.sh.log	# DKMS uses name 'make.log', so that we need ano
 
 # project name
 MODULE=fglrx
-MODULE_agpgart=fglrx_agp
 
 FGL_PUBLIC=firegl
 target_define=FGL_RX
@@ -344,7 +343,7 @@ src_file=$linuxincludes/linux/agp_backend.h
 if [ -e $src_file ];
 then
   AGP=1
-  def_agp=-D__AGP__
+#  def_agp=-D__AGP__
   echo "file $src_file says: AGP=$AGP"                             >> $logfile
 fi
 
@@ -665,10 +664,10 @@ then
   rm -f ${MODULE}.o     2>&1 | tee -a $logfile
 fi
 
-#if [ -e agpgart_fe.o ]
-#then 
-#  rm -f agpgart_fe.o 2>&1 | tee -a $logfile
-#fi
+if [ -e agpgart_fe.o ]
+then 
+  rm -f agpgart_fe.o 2>&1 | tee -a $logfile
+fi
 if [ -e agpgart_be.o ]
 then 
   rm -f agpgart_be.o 2>&1 | tee -a $logfile
@@ -700,11 +699,6 @@ then
   rmdir patch 2>/dev/null
 fi
 
-if [ -e ${MODULE_agpgart}.ko ]
-then
-  rm -f ${MODULE_agpgart}.ko     2>&1 | tee -a $logfile
-fi
-
 # ==============================================================
 # apply header file patches
 # suppress known warning in specific header file
@@ -840,6 +834,50 @@ begin_end
   rm -f $tmp_src_file $tmp_obj_file_240 $tmp_obj_file_253 $tmp_log_file_240 $tmp_log_file_253
 fi
 
+# =============================================================
+# Check if we're running a kernel version that has the SUSE 9.0 implementation of vmap
+#
+if [ $kernel_is_26x -gt 0 ]
+then
+  ## skip for 2.6.x and higher
+  echo " Assuming default VMAP API" | tee -a $logfile
+else
+  echo "Probing for VMAP API version" | tee -a $logfile
+  # create a helper source file and try to compile it into an object file
+  tmp_src_file=tmp_vmapsrc.c
+  tmp_obj_file=tmp_vmap.o
+  tmp_log_file=tmp_vmap.log
+# let's create the c file 
+  cat > $tmp_src_file <<-begin_end
+#define __KERNEL__
+#include <linux/vmalloc.h>
+int probe_vmap_version(void) {
+    struct page** pages;
+    int count= 0;
+    vmap(pages,count);
+    return 0;
+}
+begin_end
+ 
+  # check for vmap API compatibility
+  $CC -I$linuxincludes $tmp_src_file -c -o $tmp_obj_file &> $tmp_log_file
+  gcc_ret_vmap=$?
+    
+    
+# Check which VMAP API version it is and make define accordingly
+  def_vmap_api_version=
+  if [ $gcc_ret_vmap -eq 0 ]
+    then
+      echo "This is the vmap API used for SUSE 9.0 "  | tee -a $logfile
+      def_vmap_api_version=-DFGL_LINUX_SUSE90_VMAP_API
+    else
+      echo "Use default vmap API"                     | tee -a $logfile
+  fi
+  
+  # cleanup intermediate files
+  rm -f $tmp_src_file $tmp_obj_file $tmp_log_file 
+fi
+
 
 # ==============================================================
 # make agp kernel module (including object files) and check results
@@ -848,7 +886,7 @@ if [ $kernel_is_26x -gt 0 ]; then
     echo "doing Makefile based build for kernel 2.6.x and higher"   | tee -a $logfile
     cd 2.6.x
     V=${V:-0}
-    #tlog is a tempory file that will be deleted
+    #tlog is a temporary file that will be deleted
     make CC=${CC} V=${V} MODFLAGS="-DMODULE $def_for_all $def_smp $def_modversions" PAGE_ATTR_FIX=$PAGE_ATTR_FIX > tlog 2>&1 
     res=$?
     tee -a $logfile < tlog
@@ -868,27 +906,27 @@ if [ $kernel_is_26x -gt 0 ]; then
     TERMINAL_HINT=0
 
 
-	# make fglrx_agp.ko
-    echo " compiling fglrx_agp.ko module"
-    cd firegl_agpgart
-    V=${V:-0}
-    #tlog is a tempory file that will be deleted
-    make V=${V} MODFLAGS="-DMODULE $def_for_all $def_smp $def_modversions" PAGE_ATTR_FIX=$PAGE_ATTR_FIX > tlog 2>&1 
-    res=$?
-    tee -a $logfile < tlog
-    #delete tlog
-    rm -f tlog
-    cd ..
-    if [ $res -eq 0 ]; then
-        echo "AGPGART build succeeded with return value $res"               | tee -a $logfile
-	    if [ -e ${MODULE_agpgart}${kmod_extension} ]; then
-	         rm -f ${MODULE_agpgart}${kmod_extension}
-	    fi
-	    echo " finished compiling for fglrx_agp"
-	    ln -s firegl_agpgart/${MODULE_agpgart}${kmod_extension}
-    else
-        echo "AGPGART module build failed with return value $res"                  | tee -a $logfile
-    fi
+#	# make fglrx_agp.ko
+#    echo " compiling fglrx_agp.ko module"
+#    cd firegl_agpgart
+#    V=${V:-0}
+#    #tlog is a tempory file that will be deleted
+#    make V=${V} MODFLAGS="-DMODULE $def_for_all $def_smp $def_modversions" PAGE_ATTR_FIX=$PAGE_ATTR_FIX > tlog 2>&1 
+#    res=$?
+#    tee -a $logfile < tlog
+#    #delete tlog
+#    rm -f tlog
+#    cd ..
+#    if [ $res -eq 0 ]; then
+#        echo "AGPGART build succeeded with return value $res"               | tee -a $logfile
+#	    if [ -e ${MODULE_agpgart}${kmod_extension} ]; then
+#	         rm -f ${MODULE_agpgart}${kmod_extension}
+#	    fi
+#	    echo " finished compiling for fglrx_agp"
+#	    ln -s firegl_agpgart/${MODULE_agpgart}${kmod_extension}
+#    else
+#        echo "AGPGART module build failed with return value $res"                  | tee -a $logfile
+#    fi
 else
     echo "doing script based build for kernel 2.4.x and similar"    | tee -a $logfile
     
@@ -988,7 +1026,7 @@ fi
 SRC=${SOURCE_PREFIX}/${FGL_PUBLIC}_public.c
 DST=${FGL_PUBLIC}_public.o
 echo "compiling '$SRC'..." | tee -a $logfile
-cc_cmd="${CC} ${WARNINGS} -O2 -D__KERNEL__ -DMODULE -fomit-frame-pointer $def_for_all $def_machine -D${MODULE} $def_vma_api_version $def_smp $def_modversions $def_agp $patch_includes -I$linuxincludes -I$PWD -c $SRC -o $DST"
+cc_cmd="${CC} ${WARNINGS} -O2 -D__KERNEL__ -DMODULE -fomit-frame-pointer $def_for_all $def_machine -D${MODULE} $def_vma_api_version $def_vmap_api_version $def_smp $def_modversions $def_agp $patch_includes -I$linuxincludes -I$PWD -c $SRC -o $DST"
 echo "$cc_cmd" >> $logfile
 $cc_cmd 2>&1 | tee -a $logfile | grep -v "warning: pasting would not give a valid preprocessing token"
 if [ ! -e $DST ] ;
@@ -1037,20 +1075,26 @@ then
     echo "creating target directory" >> $logfile
     mkdir $target_dir | tee -a $logfile
   fi
- 
+
+  which strip > /dev/null 2>&1
+  if test $? = 0; then
+     strip -g ${MODULE}${kmod_extension} > /dev/null 2>&1
+     if test $? = 0; then	
+        echo "stripping the debug info of kernel module" >> $logfile
+     else
+        echo "could not strip the debug info of kernel module" >> $logfile
+     fi 
+  else
+     echo "could not find the strip utility on your system" >> $logfile
+  fi
+
   # for fglrx and fglrx_agp
   echo "copying ${MODULE}${kmod_extension}" >> $logfile
   if [ $INSTALL_MODULE_SUBDIRS -eq 1 ];
   then
     cp -f ${MODULE}${kmod_extension} $target_dir | tee -a $logfile
-	if [ -e ${MODULE_agpgart}${kmod_extension} ]; then
-        cp -f ${MODULE_agpgart}${kmod_extension} $target_dir | tee -a $logfile
-	fi
   else
     cp -f ${MODULE}${kmod_extension} $target_dir/${MODULE}.$OsRelease$iii${kmod_extension} | tee -a $logfile
-    if [ -e ${MODULE_agpgart}${kmod_extension} ]; then
-        cp -f ${MODULE_agpgart}${kmod_extension} $target_dir/${MODULE_agpgart}.$OsRelease$iii${kmod_extension} | tee -a $logfile
-	fi
   fi
   
   echo "copying logfile of build" >> $logfile
